@@ -41,12 +41,13 @@ my $_setup_component = sub {
 };
 
 # Public functions
-sub deref ($$) {
-   my ($x, $k) = @_;
+sub deref ($$;$) {
+   my ($x, $k, $default) = @_; my $r = $default;
 
-   blessed    $x and $x->can( $k ) and return $x->$k();
-   is_hashref $x and return $x->{ $k };
-   return;
+   if    (blessed $x and $x->can( $k )) { $r = $x->$k() // $default }
+   elsif (is_hashref $x)                { $r = $x->{ $k } // $default }
+
+   return $r;
 }
 
 sub exception (;@) {
@@ -68,9 +69,11 @@ sub load_components ($;@) {
 
    my $app      = $opts->{application};
    # If the app object is defined it must have a config attribute
+   # uncoverable condition false
    my $config   = $opts->{config} // $app->config;
    my $appclass = deref $config, 'appclass';
    # The config object/hash ref is required. It must have an appclass attribute
+   # uncoverable branch true
    $appclass or throw( Unspecified, [ 'config appclass' ] ); my $search_path;
 
    if (first_char $base eq '+') { $search_path = $base = substr $base, 1 }
@@ -92,7 +95,7 @@ sub load_components ($;@) {
    ($cfgcomps and $cfgcomps = $cfgcomps->{ $base }) or return $compos;
 
    for my $moniker (keys %{ $cfgcomps }) {
-      my $class = $base.(ucfirst $moniker);
+      my $class = "${base}::".(ucfirst $moniker);
       my @roles = @{ $_qualify->( $appclass, $cfgcomps->{ $moniker } ) };
       my $cwr   = Moo::Role->create_class_with_roles( $search_path, @roles );
 
@@ -134,10 +137,11 @@ Defines no attributes
 
 =head2 C<deref>
 
-   $value = deref $object_or_hash_ref, $key
+   $value = deref $object_or_hash_ref, $key, $optional_default;
 
 Returns the value associated with the supplied key. Accepts either an object
-or hash reference as the first argument
+or hash reference as the first argument. Returns the default if the result
+is otherwise undefined
 
 =head2 C<exception>
 
@@ -177,6 +181,8 @@ The C<components> attribute (one of the collection references held by
 L<Web::Components::Loader>) is passed to the component constructor method and
 is used by a component to discover it's dependencies
 
+An adaptor pattern is possible using the C<config_comps> attribute
+
 =head2 C<throw>
 
    throw 'message', [ 'arg1', 'arg2' ];
@@ -221,7 +227,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
